import greenfoot.*;  // （World、Actor、GreenfootImage、GreenfootSound、Greenfoot及MouseInfo）
import java.util.List;

/**
 * 燈泡。
 * 
 * @author 依瑪貓
 * @version 2012/6/16
 */
public class Light extends Actor
{
    /** 燈泡亮不亮。 */
    private boolean isOn = false;
    
    /** 燈泡亮的圖案。 */
    private GreenfootImage onImage = new GreenfootImage("light_on.png");
    
    /** 燈泡暗的圖案。 */
    private GreenfootImage offImage = new GreenfootImage("light_off.png");
    
    /**
     * 建立一個新的燈泡。
     * 
     * @param isOn 燈泡亮不亮
     */
    public Light(boolean isOn)
    {
        this.isOn = isOn;
        if (isOn)
        {
            setImage(onImage);
        }
        else
        {
            setImage(offImage);
        }
    }
    
    /**
     * 每一回合執行的動作。
     * 
     */
    public void act() 
    {
        if (Greenfoot.mouseClicked(this))
        {
            switchOnOff();
            // 取得鄰近，距離為 1 的燈泡。
            List<Light> lights = getNeighbours(1, false, Light.class);
            // 切換每顆燈泡的明暗。
            for (Light light : lights)
            {
                light.switchOnOff();
            }
        }
    }
    
    /**
     * 燈泡現在亮不亮。
     * 
     * @return 燈泡現在亮不亮。
     */
    public boolean isOn()
    {
        return isOn;
    }
    
    /**
     * 切換燈泡明暗。原來燈泡亮時，熄滅燈泡；原來未開燈時，點亮燈泡。
     * 
     */
    public void switchOnOff()
    {
        if (isOn)
        {
            isOn = false;
            setImage(offImage);
        }
        else
        {
            isOn = true;
            setImage(onImage);
        }
    }
}